const { $erte, _c, _b } = require('./erte')

/**
 * Compares the strings using the [`diff`](https://www.npmjs.com/package/diff) package,
and outputs a coloured version where strings don't match with green or red differences.
Returns a string which uses shell-codes to highlight differences.
 * @param {string} source The string to compare.
 * @param {string} target The string to comparison against.
 * @return {string}
 */
function erte(source, target) {
  return $erte(source, target)
}

/**
 * Colors the foreground using an ANSI sequence.
 * @param {string} string The string to color.
 * @param {_erte.Color} color The color to apply.
 * @return {string}
 */
function c(string, color) {
  return _c(string, color)
}

/**
 * Colors the background with specified ANSI color.
 * @param {string} string The string to color.
 * @param {_erte.Color} color The color to apply.
 * @return {string}
 */
function b(string, color) {
  return _b(string, color)
}

module.exports = erte
module.exports.c = c
module.exports.b = b

/* typal types/index.xml namespace */
/**
 * @typedef {_erte.Color} Color The color to apply.
 * @typedef {('black'|'red'|'green'|'yellow'|'blue'|'magenta'|'cyan'|'white'|'grey')} _erte.Color The color to apply.
 */
