import Diff from './diff'

const colors = {
  'black': 30,
  'red': 31,
  'green': 32,
  'yellow': 33,
  'blue': 34,
  'magenta': 35,
  'cyan': 36,
  'white': 37,
  'grey': 90,
}

const backgroundColors = {
  'black': 40,
  'red': 41,
  'green': 42,
  'yellow': 43,
  'blue': 44,
  'magenta': 45,
  'cyan': 46,
  'white': 47,
}

/**
 * @type {_erte.c}
 */
export function c(string, color) {
  const cc = colors[color]
  if (!cc) return string
  return `\x1b[${cc}m${string}\x1b[0m`
}

/**
 * @type {_erte.b}
 */
export function b(string, color) {
  const cc = backgroundColors[color]
  if (!cc) return string
  return `\x1b[${cc}m${string}\x1b[0m`
}

/**
 * @type {_erte.erte}
 */
function erte(source, target) {
  const diff = new Diff()
  const d = diff.diff(source, target)
  const m = d.map(({ added, removed, value }) => {
    let p
    const s = value.split(' ')
    if (added) {
      p = s.map(t => {
        return t.replace(/(\r?\n)$/mg, '⏎$1')
      }).map(t => c(t, 'green')).join(b(' ', 'green'))
    } else if (removed) {
      p = s.map(t => {
        return t.replace(/(\r?\n)$/mg, '⏎$1')
      }).map(t => c(t, 'red')).join(b(' ', 'red'))
    } else {
      p = c(value, 'grey')
    }
    return p
  })
  const s = m.join('')
  return s
}

export default erte

/* documentary types/index.xml */
/**
 * @typedef {('black'|'red'|'green'|'yellow'|'blue'|'magenta'|'cyan'|'white'|'grey')} Color The color to apply.
 */

/**
 * @suppress {nonStandardJsDocs}
 * @typedef {import('../types').c} _erte.c
 */
/**
 * @suppress {nonStandardJsDocs}
 * @typedef {import('../types').b} _erte.b
 */
/**
 * @suppress {nonStandardJsDocs}
 * @typedef {import('../types').erte} _erte.erte
 */
